@@ -39,6 +39,9 @@ class BootManager():
         else:
             print('BootManager object must be created in a script in the boot directory')
 
+    def create_queue(self):
+        return self.queue_manager.Queue()
+
     def create_flab_proxy(self, out_queue, in_queue):
         flab_proxy = self.flab_manager.Flab(out_queue, in_queue) # flab namespace
         flab_proxy.tasks = self.flab_manager.dict() # tasks dictionary
